fnss.topologies.datacenter.DatacenterTopology.remove_nodes_from — FNSS 0.3.2 documentation

### Navigation

- index
- modules |
- modules |
- FNSS 0.3.2 documentation »

# fnss.topologies.datacenter.DatacenterTopology.remove_nodes_from

`DatacenterTopology.` `remove_nodes_from`(nodes)

  Remove multiple nodes.

  Parameters : | nodes : iterable container A container of nodes (list, dict, set, etc.). If a node in the container is not in the graph it is silently ignored.

  See also

  `remove_node`

  Examples

      >>> G = nx.Graph()   # or DiGraph, MultiGraph, MultiDiGraph, etc
      >>> G.add_path([0,1,2])
      >>> e = G.nodes()
      >>> e
      [0, 1, 2]
      >>> G.remove_nodes_from(e)
      >>> G.nodes()
      []

### Navigation

- index
- modules |
- modules |
- FNSS 0.3.2 documentation »